@@ -397,7 +397,7 @@ async fn response() {
         .await
         .unwrap();
     assert_eq!(resp.status(), StatusCode::NOT_FOUND);
-    assert_eq!(resp.content_type(), Some("text/plain"));
+    assert_eq!(resp.content_type(), Some("text/plain; charset=utf8"));
     assert_eq!(resp.take_body().into_string().await.unwrap(), "code: 404");
 }
 
@@ -440,7 +440,7 @@ async fn bad_request_handler() {
         .await
         .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
-    assert_eq!(resp.content_type(), Some("text/plain"));
+    assert_eq!(resp.content_type(), Some("text/plain; charset=utf8"));
     assert_eq!(resp.take_body().into_string().await.unwrap(), "code: 200");
 
     let mut resp = ep
@@ -453,7 +453,7 @@ async fn bad_request_handler() {
         .await
         .unwrap();
     assert_eq!(resp.status(), StatusCode::BAD_REQUEST);
-    assert_eq!(resp.content_type(), Some("text/plain"));
+    assert_eq!(resp.content_type(), Some("text/plain; charset=utf8"));
     assert_eq!(
         resp.take_body().into_string().await.unwrap(),
         r#"!!! failed to parse parameter `code`: Type "integer(uint16)" expects an input value."#
@@ -502,7 +502,7 @@ async fn bad_request_handler_for_validator() {
         .await
         .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
-    assert_eq!(resp.content_type(), Some("text/plain"));
+    assert_eq!(resp.content_type(), Some("text/plain; charset=utf8"));
     assert_eq!(resp.take_body().into_string().await.unwrap(), "code: 50");
 
     let mut resp = ep
@@ -515,7 +515,7 @@ async fn bad_request_handler_for_validator() {
         .await
         .unwrap();
     assert_eq!(resp.status(), StatusCode::BAD_REQUEST);
-    assert_eq!(resp.content_type(), Some("text/plain"));
+    assert_eq!(resp.content_type(), Some("text/plain; charset=utf8"));
     assert_eq!(
         resp.take_body().into_string().await.unwrap(),
         r#"!!! failed to parse parameter `code`: verification failed. maximum(100, exclusive: false)"#
